@@ -1,5 +1,5 @@
 __title__ = 'xenon_view_sdk'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 __author__ = 'Xenon'
 __copyright__ = 'Copyright 2021 Xenon'
 '''
@@ -231,7 +231,7 @@ class Xenon(object, metaclass=Singleton):
     def checkoutCanceled(self):
         content = {
             'superOutcome': 'Customer Checkout',
-            'outcome': 'Checkout Canceled',
+            'outcome': 'Canceled',
             'result': 'fail'
         }
         self.outcomeAdd(content)
